/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.jpa.entity;

import java.util.Date;
import org.apache.commons.lang3.StringUtils;
import org.apache.syncope.core.persistence.api.entity.AnnotatedEntity;
import org.apache.syncope.core.spring.security.AuthContextUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public abstract class AbstractSysInfoListener {

    protected static final Logger LOG = LoggerFactory.getLogger(AnnotatedEntityListener.class);

    protected void setSysInfoOnAnnotatedEntity(final AnnotatedEntity entity) {
        LOG.debug("Set system properties for '{}'", entity);

        String username = AuthContextUtils.getUsername()
                + AuthContextUtils.getDelegatedBy().map(d -> " [delegated by " + d + "]").orElse(StringUtils.EMPTY);

        Date now = new Date();

        if (entity.getCreationDate() == null) {
            LOG.debug("Set creation date '{}' and creator '{}' for '{}'", now, username, entity);
            entity.setCreationDate(now);
            entity.setCreator(username);
        }

        LOG.debug("Set last change date '{}' and modifier '{}' for '{}'", now, username, entity);
        entity.setLastModifier(username);
        entity.setLastChangeDate(now);
    }
}
